/*
    Copyright (C) 2010 - 2012 EngSaS - Engineering Solutions and Services Langenbach. All rights reserved.

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    MA 02110-1301  USA.
*/

#ifndef EABOUTDIALOG_H
#define EABOUTDIALOG_H

#include "eglobal.h"
#include "edialog.h"

class EAboutModel;

namespace Ui {
	class EAboutDialog;
}

#include <QUrl>

/**
	* @brief An About dialog for your application in EngSaS-Layout.
	*
	* The given EAboutModel is delete by the dialog.
	*/
class E_CORE_EXPORT EAboutDialog : public EDialog
{
	Q_OBJECT
	public:
		EAboutDialog(QPixmap logo, QString name, QString version,
								 QUrl url, EAboutModel *model,
								 QWidget* parent = 0, Qt::WindowFlags flags = 0 );

		/**
			* @brief Sets the application logo on the right side of the dialog.
			*
			*/
		void setLogo(QPixmap logo);
		/**
			* @brief Sets the name of the application on the top.
			*/
		void setName(QString name);
		/**
			* @brief Sets the version of the application.
			*/
		void setVersion(QString version);
		/**
			* @brief Sets the application url.
			*
			* The url can be absolute or relative to engsas.de. In last case
			* the beginning points to the page related to current chosen
			* language, like shown in the example below.
			* @code
			*		// set the url to http://en.engsas.de/meganizer in english
			*		// and http://www.engsas.de/meganizer in german translation
			*		setRelativeUrl("meganizer") 
			* @endcode
			*/
		void setApplicationUrl(QUrl url);
		void setModel(EAboutModel *model);

	private slots:
		void openLink(QString url);
		
	private:
		void setupTextLabel();
		QString myName, myVersion;
		QUrl myUrl;
		Ui::EAboutDialog *ui;
};

#endif // EABOUTDIALOG_H
