/*
    Copyright (C) 2010 - 2012 EngSaS - Engineering Solutions and Services Langenbach. All rights reserved.

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    MA 02110-1301  USA.
*/

#ifndef SETTINGSGENERAL_H
#define SETTINGSGENERAL_H

#include "esettingswidget.h"
#include "eglobal.h"

namespace Ui {
		class EDBSettingsWidget;
}

/**
	* @brief ESettingsWidget to configure database host, type and database name.
	*
	* To use those settings, just call the appropriate function host(), driver()
	* or database().
	*
	* If you only want to show some of the sqlDrivers(), use setAvailableDrivers().
  */
class E_CORE_EXPORT EDBSettingsWidget : public ESettingsWidget {
  Q_OBJECT
  public:
		EDBSettingsWidget(QWidget *parent = NULL, Qt::WindowFlags flags = 0);
		~EDBSettingsWidget();

		/**
			* @brief Returns all installed sql drivers on this system.
			*/
		static QStringList sqlDrivers();

		/**
			* @brief The list of drivers, which the user can choose one of.
			*
			* If noe drivers are set (e.g. function is not called at all)
			* sqlDrivers() is used.
			*/
		void setAvailableDrivers(QStringList drivers);

		/**
			* @brief Returns the database host from settings.
			*/
		static QString host();
		/**
			* @brief Returns the database driver from settings.
			*/
		static QString driver();
		/**
			* @brief Returns the database name from settings.
			*/
		static QString database();
		/**
			* @brief Returns whether SSL is enabled or not from settings.
			*/
		static bool ssl();

  public slots:
    bool saveSettings(QString &errorString);

	private slots:
		void typeChanged ( QString text );

	private:
		Ui::EDBSettingsWidget *m_ui;
};

#endif // SETTINGSGENERAL_H
