/*
    Copyright (C) 2010 - 2012 EngSaS - Engineering Solutions and Services Langenbach. All rights reserved.

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    MA 02110-1301  USA.
*/

#ifndef EDBUPDATEWIDGET_H
#define EDBUPDATEWIDGET_H

#include "eglobal.h"
#include "esetupwizardwidget.h"

namespace Ui {
	class EDBUpdateWidget;
}

class ESqlInit;

#include <QPointer>

/**
	* @brief Widget to create and update database schemas defined with ESqlInit.
	* @ingroup SQL
	*/
class E_CORE_EXPORT EDBUpdateWidget : public ESetupWizardWidget
{
	Q_OBJECT
	public:
		enum Needed{
			Nothing, /**< Neither Settings nor update is needed */
			Settings, /**< Only Setting is needed */
			Update, /**< Only update is needed */
			Both /**< Settings and update are needed */
		};
		
		EDBUpdateWidget ( ESqlInit *newDBInit, ESetupWizardObject *newObject = 0, QWidget *parent = 0, Qt::WindowFlags flags = 0 );
		EDBUpdateWidget ( QString title, ESqlInit *newDBInit, ESetupWizardObject *newObject = 0, QWidget *parent = 0, Qt::WindowFlags flags = 0 );
		/**
			* @todo delete ESqlInit.
			*/
		~EDBUpdateWidget();

	public slots:
		EDBUpdateWidget::Needed needed();
		bool finish();
		bool saveSettings(QString &error);

	private slots:
		void errorByPass ( const QString &string );
		void warningByPass ( const QString &string );
		void informationByPass ( const QString &string );

		void setRange ( int num );
		void finishedStep();
		void actualStep ( QString msg );
		void log ( QString msg );

	private:
		QPointer<ESqlInit> sqlInit;
		Ui::EDBUpdateWidget *ui;
};

#endif // EDBUPDATEWIDGET_H
