/*
    Copyright (C) 2010 - 2012 EngSaS - Engineering Solutions and Services Langenbach. All rights reserved.

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    MA 02110-1301  USA.
*/

#ifndef ELIBRARY_H
#define ELIBRARY_H

#include "eglobal.h"

class EPart;
class ESettingsModelItem;
class ECmdLineOption;
class EAboutPerson;

#include <QDir>
#include <QUrl>

/**
	* @brief This class provides information about the LibEngsas and loads EPart's.
	*
	* Therefore it can be used to determine EPart directory and more.
	*/
class E_CORE_EXPORT ELibrary
{
	public:
		/**
			* @brief Returns the directory containing EPart's
			*/
		static QDir ePartDirectory();
		/**
			* @brief This function loads an EPart and does nothing with it.
			* 
			* This function should be used to get the EPart the first time to
			* set up the application and before the creation of KApplication or
			* QApplication. After load it correctly again with loadEPart(), if
			* the application was started.
			*/
		static EPart* loadEPartFirstTime(QString ePart, QString &error);
		/**
			* @brief Tries to load the EPart with name or absolute path @p ePart.
			*
			* If only a name is specified, the EPart is searched at the standard
			* EPart directory, which is returned by ePartDirectory(). The path
			* can be accessed within CMake with help of ${LIBENGSAS_EPART_DIR}
			* after LibEngsas has been found.
			*
			* If the EPart can be loaded, it also tries to load the translations
			* and resources for this part. To setup the meta data call setupApplication()
			* after creating your QApplication or KApplication instance
			* or leave @p doSetupApplication true to let this function do the setup.
			* 
			* @note This function deletes @p part.
			*
			* @see setupApplication(QString, QString&)
			* @see loadTranslations(QString, QString&)
			* @see loadResources(QString, QString&)
			*/
		static EPart* loadEPart ( EPart *part, QString ePart, QString &error, bool doSetupApplication = true);
		/**
			* @brief Wrapper for setupQApplication( QString, QString& )
			*/
		static bool setupApplication ( EPart *part, QString &error );
		/**
			* @brief Sets the QApplication::organizationName() and QApplication::applicationName()
			*   to proper values
			*/
		static bool setupApplication ( QString shortName, QString version, QString& error );
		/**
			* @brief Wrapper for loadTranslations (QString, QString&)
			*/
		static bool loadTranslations ( EPart *part, QString &error );
		/**
			* @brief Loads all translations from @p dir.
			* 
			* Also translations for LibEngsas and Qt library are loaded.
			*/
		static bool loadTranslations ( QString dir, QString& error );
		/**
			* @brief Wrapper for loadResources(QString, QString&)
			*/
		static bool loadResources ( EPart *part, QString &error );
		/**
			* @brief Loads the resources at @p dir. It also loads the resources of LibEngsas
			*/
		static bool loadResources ( QString dir, QString &error );

		/**
			* @brief Returns the name of the manufacturer.
			*/
		static QString manufacturer();
		/**
			* @brief Returns the website of EngSaS for the active language.
			*/
		static QUrl website();
		/**
			* @brief Returns a ESettingsModelItem with all pages for ELibrary settings.
			*/
		static ESettingsModelItem *settingsModelItem();
		/**
			* @brief Returns a list of persons, related to LibEngsas.
			*/
		static EngSaS::AboutPersons aboutPersons();
};

#endif // ELIBRARY_H
