/*
    Copyright (C) 2010 - 2012 EngSaS - Engineering Solutions and Services Langenbach. All rights reserved.

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    MA 02110-1301  USA.
*/

#ifndef EOPENFILEEXTERNAL_H
#define EOPENFILEEXTERNAL_H

#include "eglobal.h"
#include "eobject.h"

class EMimeTypeModel;
class EMimeType;

#include <QFileInfo>

/**
	* @brief Tries to open a given url or file in an external Application.
	*
  *
  * It can detect the filetype with help of the extension
  * or the file type can be given. In last case the file is
	* opened with the related application without checking, if it
	* is a file of that type.
	* To open a file use openFile(QString, QString, QObject*) or
	* openFile(QFileInfo, QString, QObject*)
	* It uses the KDE MimeType system, if BINDINGS_KDE is activated
  * and the main application is an KApplication.
  */
class E_CORE_EXPORT EOpenFileExternal : public EObject{
	Q_OBJECT
	public:
		EOpenFileExternal(QObject *parent = 0);
		~EOpenFileExternal();

		/**
			* returns a list of known MimeTypes
			*/
		static EMimeTypeModel* mimeTypes();
		/**
			* @brief Returns the settings group.
			*/
		static QString group();

		void setFile(QString file, QString mimeType = "");
		void setFile(QFileInfo file, QString mimeType = "");

		static bool openFile(QString file, QString mimeType, QObject *parent);
		static bool openFile(QFileInfo file, QString mimeType, QObject *parent);
		bool openFile(QString file, QString mimeType = "");
		bool openFile(QFileInfo file, QString mimeType = "");
		bool open();

	private:
		QString myFile;
		EMimeType *myType;
		EMimeTypeModel *model;
		bool isStream;

    /**
      * trys to detect the mimetype autometically (or returns myType, if set)
      * right now it uses the suffix
      * @todo detect mimetype by opening it and reading the header of the file
      * @todo it should create a new one if it detects an unknown MimeType
      */
		EMimeType *detectType();
    /**
      * Opens the SearchExternalApp dialog to let the user add other applications
      * and choose one of the listed applications
      */
		QString searchApp(EMimeType* mimeType);
};
#endif // EOPENFILEEXTERNAL_H
