/*
    Copyright (C) 2010 - 2012 EngSaS - Engineering Solutions and Services Langenbach. All rights reserved.

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    MA 02110-1301  USA.
*/

#ifndef EPUSHBUTTON_H
#define EPUSHBUTTON_H

#include "eglobal.h"
#include <QPushButton>

/**
	* @brief QPushButton replacement, which handles "iconsAndText"-option and QIcon::fromTheme.
	*
	* This button hides the text, if:
	*  - iconAndText is false
	*  - and icon is not null
	*  - and showText is false (Default)
	* @see EAction
	*/

class E_CORE_EXPORT EPushButton : public QPushButton
{
	Q_OBJECT
	/**
		* if set to true, the text will be shown in any case
		* if set to false (default), the text will only be shown, if no icon is set
		* or iconsAndText is true
		*/
	Q_PROPERTY(bool showText READ showText WRITE setShowText)
	public:
		EPushButton ( QWidget *parent = 0 );
		EPushButton ( const QString & text, QWidget * parent = 0 );
		/**
			* @see setIcon(QString, QString)
			*/
		EPushButton ( QString standardIconName, QString iconPath, const QString & text, QWidget * parent = 0 );
		/**
			* @brief Determines, if the text is hidden (Default), when an icon is there or not.
			*/
		void setShowText(bool anytime = true);
		bool showText() const;
		void setIcon ( const QIcon & icon );
		/**
			* @brief Tries to use QIcon::fromTheme(@p standardIconName) if possible, otherwise QIcon(@p iconPath) is used.
			*
			* The QIcon::fromTheme requires at least Qt 4.6.
			*/
		void setIcon ( QString standardIconName, QString iconPath);
		void setText ( const QString & text );
		
	private:
		void init(QString text = QString());
		
		bool myShowText, iconsAndText;
		QString myText;
};

#endif // EPUSHBUTTON_H
