/*
    Copyright (C) 2010 - 2012 EngSaS - Engineering Solutions and Services Langenbach. All rights reserved.

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    MA 02110-1301  USA.
*/

#ifndef ESETTINGSMODEL_H
#define ESETTINGSMODEL_H

#include "eglobal.h"
#include "eabstractitemmodel.h"

class ESettingsModelItem;

/**
	* @brief Model to present the user a tree of possible settings pages.
	*
	* @note Must be setup completly before showing in a view, because no signals
	*   to indicate changes are implemented.
	*/
class E_CORE_EXPORT ESettingsModel : public EAbstractItemModel
{
	Q_OBJECT
	public:
		ESettingsModel(QObject *parent = 0);
    ~ESettingsModel();

		bool addItem(ESettingsModelItem *item);
		ESettingsModelItem *itemFromIndex(QModelIndex index) const;
		bool save(QString &error);

		// standard api
		QVariant data(const QModelIndex& index, int role = Qt::DisplayRole) const;
		int columnCount(const QModelIndex& parent = QModelIndex()) const;
		int rowCount(const QModelIndex& parent = QModelIndex()) const;
		QModelIndex parent(const QModelIndex& child) const;
		QModelIndex index(int row, int column, const QModelIndex& parent = QModelIndex()) const;
		QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const;

	public slots:
		inline void reloadSettings(){ emit doReloadSettings(); };
		
	private slots:
		inline void reloadSettingsRequestByPass(){ reloadRequested = true; };
		
	private:
		ESettingsModelItem* root;
		/**
			* @brief Set to true by reloadSettingsRequestByPass(), if a reloadSettingsRequest is catched.
			*/
		bool reloadRequested;

	signals:
		void reloadSettingsRequest();
		void doReloadSettings();
};

#endif // ESETTINGSMODEL_H
