/*
    Copyright (C) 2010 - 2012 EngSaS - Engineering Solutions and Services Langenbach. All rights reserved.

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    MA 02110-1301  USA.
*/


#ifndef ESETUPWIZARD_H
#define ESETUPWIZARD_H

#include "eglobal.h"
#include "edialog.h"

namespace Ui {
	class ESetupWizard;
}

#include "esetupwizardobject.h"

/**
	* @brief A wizard to setup all needed settings and stuff like databases.
	*
	* Please be aware, that you do not need to add an ESetupWizardDBDump object, because
	* this wizard adds one automatically before the first ESetupWizardDB object.
	*
	* Use this sequence to start the wizard:
	* @code
	*		ESetupWizardObjects objects;
	*		// append your ESetupWizardObjects to the list
	*		...
	*		// setup and show the wizard if needed
	*		ESetupWizard wizard;
	*		connectByPass(&wizard);
	*		wizard.loadObjects(objects);
	*		if(wizard.isNeeded())
	*			wizard.exec();
	* @endcode
  *
  * @todo Reload is not working like it does in meganizer, because we can not recreate the ESetupWizardObjects.
	* @todo Catch all errors, warnings and information and create an setup report, which can be exported by the user.
  */

class E_CORE_EXPORT ESetupWizard: public EDialog
{
	Q_OBJECT
	public:
		ESetupWizard (QWidget *parent = 0, Qt::WindowFlags fl = 0);
    ~ESetupWizard();
		bool isNeeded();
		void reload();
		/**
			* @brief Function to setup all needed ESetupWizardObjects.
			*/
		void loadObjects(EngSaS::SetupWizardObjects objects);
		/**
			* @brief Sets the logo of the application.
			*
			* If not set, QApplication::windowIcon() is used.
			*/
		void setLogo(QIcon logo);
		/**
			* @brief Sets the application name into @p name.
			*
			* If not set, QApplication::name() is used.
			*/
		void setApplicationName(QString name);

	public slots:
		int exec();

	private slots:
		void setProgress();
		/**
			* @todo handling of reloads and related with it the error handling of finish()
			*/
		void next();
		void back();
		void markReload();

	private:
		void loadObjects();
		void addObjectsWidgets(ESetupWizardObject *object);
		void unloadObject(ESetupWizardObject* object);

		QString firstTitle;
		QString shortName;
		bool needed, doReload;
		EngSaS::SetupWizardObjects objects;
		/**
			* A list of objects, which are automatically added.
			* (E.g.: ESetupWizardDB). But they must be unloaded
			* at the destructor.
			*/
		EngSaS::SetupWizardObjects autoAddedObjects;
		Ui::ESetupWizard *ui;
};

#endif // SETUPWIZARD_H
