/*
    Copyright (C) 2012 EngSaS - Engineering Solutions and Services Langenbach. All rights reserved.

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/


#ifndef ESPREADSHEETCELL_H
#define ESPREADSHEETCELL_H

#include "eglobal.h"

#include <QVariant>
#include <QFont>
#include <QBrush>

/**
	* @brief Represents one cell of a ESpreadsheet
	* @ingroup Spreadsheets
	*
	* It contains the value (see value()) of a cell and also the formatting (font(), alignment(), foreground(), background()).
	* An ESpreadsheetCell is isValid(), if row() and column() is greater or equal to 0 (default -1).
	*
	* @see ESpreadsheet
	* @see ESpreadsheetHandler
	* @see ESpreadsheetProvider
	*/
class E_CORE_EXPORT ESpreadsheetCell
{
	public:
    ESpreadsheetCell();
		ESpreadsheetCell(int row, int column, QVariant value = QVariant());
		
		/**
			* @brief Returns true, if the row() and column() is set to a value greator or equal 0.
			*/
		bool isValid() const;
		int row() const;
		void setRow(int row);
		int column() const;
		void setColumn(int column);

		QVariant value() const;
		void setValue(QVariant value);
		QFont font() const;
		void setFont(QFont font);
		void setFont(QVariant font);
		Qt::Alignment alignment() const;
		void setAlignment(int alignment);
		void setAlignment(QVariant alignment);
		QBrush foreground() const;
		void setForeground(QBrush foreground);
		void setForeground(QVariant foreground);
		QBrush background() const;
		void setBackground(QBrush background);
		void setBackground(QVariant background);
		
	private:
		void init();

		int myRow, myColumn;
		QVariant myValue;
		QFont myFont;
		QBrush myForeground, myBackground;
		Qt::Alignment myAlignment;
};

#endif // ESPREADSHEETCELL_H
