/*
		Copyright (C) 2013 EngSaS - Engineering Solutions and Services Langenbach. All rights reserved.

		This library is free software; you can redistribute it and/or
		modify it under the terms of the GNU Lesser General Public
		License as published by the Free Software Foundation; either
		version 2.1 of the License, or (at your option) any later version.

		This library is distributed in the hope that it will be useful,
		but WITHOUT ANY WARRANTY; without even the implied warranty of
		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
		Lesser General Public License for more details.

		You should have received a copy of the GNU Lesser General Public
		License along with this library; if not, write to the Free Software
		Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
		MA 02110-1301  USA.
*/

#ifndef ESPREADSHEETPROVIDER_H
#define ESPREADSHEETPROVIDER_H

#include "eglobal.h"
#include "eobject.h"

class ESettingsWidget;

class QFile;

/**
	* @brief Interface to implement spreadsheet providers (e. g. to create excel files or ods, ...)
	* @ingroup Spreadsheets
	*
	* An ESpreadsheetProvider is an interface, to add support for specific spreadsheet
	* file types (like csv, xls, ods, ...). A provider must be build as a plugin and placed
	* at the ENGSAS_ESPREADSHEET_PROVIDER_PLUGIN_DIR, which is per default below the EPart directory.
	*/
class E_CORE_EXPORT ESpreadsheetProvider : public EObject
{
	public:
		virtual ~ESpreadsheetProvider() {}

		virtual QString name() const = 0;
		virtual QString providerId() const = 0;
		virtual ESettingsWidget* settingsWidget() const = 0;

		virtual QStringList filters() const = 0;
		/**
			* @brief Return true, if (more than one) sheet is supported.
			*
			* E. g. CSV returns false, but XLS or ODS return true.
			*/
		virtual bool sheetsSupported() const = 0;
		virtual bool create(QFile *file) = 0;
		virtual bool load(QFile *file) = 0;
		virtual bool writeData() = 0;
		/**
			* @brief Closes the opened file and deletes the spreadsheets.
			*/
		virtual void close() = 0;
		virtual ESpreadsheet* appendSpreadsheet(QString name) = 0;
		virtual EngSaS::Spreadsheets spreadsheets() = 0;
};

#if QT_VERSION >= 0x050000
#define LibEngsasESpreadsheetProviderIID "de.engsas.libengsas.ESpreadhsheetProvider"
Q_DECLARE_INTERFACE(ESpreadsheetProvider, LibEngsasESpreadsheetProviderIID)
#else
Q_DECLARE_INTERFACE ( ESpreadsheetProvider, "LibEngsas.ESpreadsheetProvider/0.1.0" );
#endif

#endif // ESPREADSHEETPROVIDER_H
