/*
    Copyright (C) 2010 - 2012 EngSaS - Engineering Solutions and Services Langenbach. All rights reserved.

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    MA 02110-1301  USA.
*/


#ifndef EUPDATENOTICEDIALOG_H
#define EUPDATENOTICEDIALOG_H

#include "eglobal.h"
#include "edialog.h"

namespace Ui {
	class EUpdateNoticeDialog;
}

#include <QUrl>

class QNetworkReply;

/**
	* @brief Used to inform about new available versions.
	*
	* It checks http://ftp.engsas.de/versions.xml for new
	* available versions of the current application. The name
	* of the application can be given or otherwise
	* QApplication::applicationName() is used. Also the current
	* Version can be set via check() or if empty,
	* QApplication::applicationVersion() is used.
	* 
	* To allow the user to confgire it's behaviour, integrate
	* the EUpdateNoticeSettings widget into your settings dialog.
	* This widget is also contained in the designer plugins.
	*
	* To use this class with QApplication use the code snippet:
	* @code
	* // make sure the update dialog is only shown,
	* // if no package management software is invoved
	* #if not defined(BUILD_PACKAGE) or defined(Q_OS_WIN32)
	* // Url will be expanded to http://en|www.engsas.de/example
	* // and the object deletes itself after finishing the check
	* EUpdateNoticeDialog *dialog = new EUpdateNoticeDialog(QUrl("example", this);
	* connectByPass(dialog);
	* dialog->check();
	* #endif
	* @endcode
	* @see EUpdateNoticeDialog(QWidget*, Qt::WindowFlags)
	* @see EUpdateNoticeDialog(QString, QWidget*, Qt::WindowFlags)
	* @see check()
	* @see EUpdateNoticeSettings
	*/
class E_CORE_EXPORT EUpdateNoticeDialog : public EDialog
{
	Q_OBJECT
	public:
		/**
			* @brief Uses QApplication::applicationName() as application name.
			*
			*/
		EUpdateNoticeDialog(QIcon logo, QUrl url,
												QWidget *parent = 0, Qt::WindowFlags flags = 0);
		/**
			* @brief Uses @p appName as application name.
			*/
		EUpdateNoticeDialog(QString appName, QIcon logo, QUrl url,
												QWidget *parent = 0, Qt::WindowFlags flags = 0);
		/**
			* @brief Starts the check.
			*
			* If @p currentVersion is empty, QApplication::applicationVersion()
			* is used as current version.
			*/
		void check(QString currentVersion = QString());

	private slots:
		void openLink(QString url);
		void dontShowAgain(int state);
		void replyFinished();
		/**
			* @brief Compares the currentVersion against the @p actualVersion.
			*
			* Internally it uses the Version class, but to avoid
			* dependency in this header file, Version is not used here!
			*/
		void compare(QString version);
		
	private:
		void init(QIcon logo, QUrl url);
		QString appName;
		QString currentVersion;
		QUrl url;
		Ui::EUpdateNoticeDialog *ui;
};

#endif // EUPDATENOTICEDIALOG_H
