/*
		Copyright (C) 2010 - 2013 EngSaS - Engineering Solutions and Services Langenbach. All rights reserved.

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    MA 02110-1301  USA.
*/

#ifndef ECLOSEMODALWIDGETTHREAD_H
#define ECLOSEMODALWIDGETTHREAD_H

#include <QThread>

#include "etesting.h"
#include "eclosemodalwidgetevent.h"

class ECloser;

#include <QList>

/**
	* @brief This class can be used to close blocking widgets.
	* 
	* It is especially useful during tests, where QDialogs popping up
	* and must be closed again.
	* Used as shown below, the blocking widget is closed 3 seconds after
	* the thread was started. To modify the time see ECloseModalWidgetThread().
	*
	* Per default it uses the escape sequence to close the dialog. But you can specify
	* a list of events, which is used instead with setEvents() before calling start().
	* 
	* You can use it as shown in the following example or look at
	* EFileDialogTest::getExistingDirectory().
	* @code
	* ECloseModalWidgetThread thread;
	* thread.setEvents(); // (If you want to use other events, than the ESC key
	* thread.start();
	* if(!thread.waitForStart())
	*   QSKIP("Could not start thread", SkipSingle);
	* // Open your blocking widget here
	* 
	* thread.stopThread();
	* @endcode
	* 
	*/
class E_TESTING_EXPORT ECloseModalWidgetThread : public QThread
{
	Q_OBJECT
	public:
		/**
			* You can specify the time until the close event is send after the
			* thread is started with @p timeToCloseEvent.
			*
			*/
		ECloseModalWidgetThread(uint timeToCloseEvent = 3000);
		~ECloseModalWidgetThread();
		void setEvents(ECloseModalWidgetEvents eventList);
		void stopThread();
		void run();
		bool isStarted();
		bool waitForStart();

	private slots:
		void setStarted();

	private:
		bool finishedStartup;
		ECloser *closer;
		uint timeToCloseEvent;
		ECloseModalWidgetEvents events;
};

#endif // ECLOSEMODALWIDGETTHREAD_H
