######################
#
#    Copyright (C) 2010 - 2014 EngSaS - Engineering Solutions and Services Langenbach. All rights reserved.
#
#    This library is free software; you can redistribute it and/or
#    modify it under the terms of the GNU Lesser General Public
#    License as published by the Free Software Foundation; either
#    version 2.1 of the License, or (at your option) any later version.
#
#    This library is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#    Lesser General Public License for more details.
#
#    You should have received a copy of the GNU Lesser General Public
#    License along with this library; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
#    MA 02110-1301  USA.
#
######################

# - Try to find LibEngsas and LibEngsas-testing
# Once done this will define
#
#  LIBENGSAS_FOUND                  - system has LibEngsas
#  LIBENGSAS_VERSION                - LibEngsas major version
#  LIBENGSAS_VERSION_MAJOR          - LibEngsas major version
#  LIBENGSAS_VERSION_MINOR          - LibEngsas major version
#  LIBENGSAS_VERSION_PATCH          - LibEngsas major version
#  LIBENGSAS_LIBRARY_DIR            - the LibEngsas top level directory
#  LIBENGSAS_INCLUDE_DIR            - the LibEngsas include directory
#  LIBENGSAS_LIBRARIES              - the libraries needed to LibEngsas
#  LIBENGSAS_EPARTEXE               - the full path to the epartexe executable
#                                     (Can be used to easily install it into your application directory under windows)
#  LIBENGSAS_EPARTEXE_DEBUG         - Debug version of epartexe
#  LIBENGSAS_EPART_DIR              - the directory, where EParts should be installed to
#  LIBENGSAS_SHARE_DIR							- Share directory of libengsas (contains ressources, translations, depedencies, ...)
#
#  LIBENGSAS_TESTING_FOUND          - system has LibEngsas-testing
#  LIBENGSAS_TESTING_INCLUDE_DIR    - the LibEngsas-testing include directory
#  LIBENGSAS_TESTING_LIBRARIES      - the libraries needed to LibEngsas-testing
#
#  LIBENGSAS_CHARTS_FOUND           - system has LibEngsas-charts
#  LIBENGSAS_CHARTS_INCLUDE_DIR     - the LibEngsas-charts include directory
#  LIBENGSAS_CHARTS_LIBRARIES       - the libraries needed to LibEngsas-charts
#
# use pkg-config to get the directories and then use these values
# in the FIND_PATH() and FIND_LIBRARY() calls

# Copyright (C) 2010  EngSaS - Engineering Solutions and Services Langenbach. All rights reserved.

INCLUDE(FindPackageHandleStandardArgs)

IF(WIN32)
	SET(LIBENGSAS_EPART_DIR .)
	INCLUDE(SelectLibraryConfigurations)
ELSE(WIN32)
	SET(LIBENGSAS_EPART_DIR "/usr/lib//libengsas")
ENDIF(WIN32)
IF (LIBENGSAS_INCLUDE_DIR AND LIBENGSAS_LIBRARIES AND LIBENGSAS_EPART_DIR AND LIBENGSAS_EPARTEXE AND LIBENGSAS_SHARE_DIR)
	# in cache already
	SET(LIBENGSAS_FOUND TRUE)
ELSE (LIBENGSAS_INCLUDE_DIR AND LIBENGSAS_LIBRARIES AND LIBENGSAS_EPART_DIR AND LIBENGSAS_EPARTEXE AND LIBENGSAS_SHARE_DIR)

	IF (WIN32)
		FIND_PATH(LIBENGSAS_LIBRARY_DIR
			NAMES "engsas.dll" "libengsas.dll"
			HINTS "C:/Program Files" "C:/Program Files (x86)"
			PATH_SUFFIXES "libengsas"
		)
		SET(LIBENGSAS_SHARE_DIR ${LIBENGSAS_LIBRARY_DIR})
		FIND_LIBRARY(LIBENGSAS_LIBRARY_RELEASE NAMES engsas.dll libengsas.dll HINTS "${LIBENGSAS_LIBRARY_DIR}")
		FIND_LIBRARY(LIBENGSAS_LIBRARY_DEBUG NAMES engsasd.dll libengsasd.dll HINTS "${LIBENGSAS_LIBRARY_DIR}")
		SELECT_LIBRARY_CONFIGURATIONS(LIBENGSAS)
		FIND_PROGRAM(LIBENGSAS_EPARTEXE NAMES epartexe.exe HINTS "${LIBENGSAS_LIBRARY_DIR}")
		FIND_PROGRAM(LIBENGSAS_EPARTEXE_DEBUG NAMES epartexed.exe HINTS "${LIBENGSAS_LIBRARY_DIR}")
		FIND_PATH(LIBENGSAS_INCLUDE_DIR NAMES eglobal.h HINTS "${LIBENGSAS_LIBRARY_DIR}" PATH_SUFFIXES include/core)
	ELSE(WIN32)
		FIND_PACKAGE(PkgConfig)
#     pkg_check_modules(PC_QCA2 QUIET qca2)
		pkg_check_modules(PC_LIBENGSAS libengsas)
		SET(LIBENGSAS_DEFINITIONS ${PC_LIBENGSAS_CFLAGS_OTHER})
		FIND_PATH(LIBENGSAS_SHARE_DIR
			NAMES depends rcc lang
			HINTS /usr/share/libengsas /usr/local/share/libengsas
		)
		FIND_LIBRARY(LIBENGSAS_LIBRARIES
			WIN32_DEBUG_POSTFIX d
			NAMES engsas
			HINTS "${PC_LIBENGSAS_LIBDIR}" "${PC_LIBENGSAS_LIBRARY_DIRS}"
		)
		FIND_PROGRAM(LIBENGSAS_EPARTEXE
			NAME epartexe epartexe-kde
			HINTS "/usr/bin" "/usr/local/bin" "/usr/bin"
		)
		FIND_PATH(LIBENGSAS_INCLUDE_DIR eglobal.h
			HINTS "${PC_LIBENGSAS_INCLUDEDIR}" "${PC_LIBENGSAS_INCLUDE_DIRS}"
			PATH_SUFFIXES core
		)
	ENDIF (WIN32)

	find_package_handle_standard_args(LIBENGSAS DEFAULT_MSG  LIBENGSAS_LIBRARIES LIBENGSAS_INCLUDE_DIR LIBENGSAS_EPARTEXE LIBENGSAS_SHARE_DIR)

# mark_as_advanced(QCA2_INCLUDE_DIR QCA2_LIBRARIES)

ENDIF (LIBENGSAS_INCLUDE_DIR AND LIBENGSAS_LIBRARIES AND LIBENGSAS_EPART_DIR AND LIBENGSAS_EPARTEXE AND LIBENGSAS_SHARE_DIR)

###########################
#
# LibEngsas-testing
#
###########################

IF (LIBENGSAS_TESTING_INCLUDE_DIR AND LIBENGSAS_TESTING_LIBRARIES)
	# in cache already
	SET(LIBENGSAS_TESTING_FOUND TRUE)
ELSE (LIBENGSAS_TESTING_INCLUDE_DIR AND LIBENGSAS_TESTING_LIBRARIES)

	IF (WIN32)
		SET(LIBENGSAS_TESTING_LIBRARY_DIR "${LIBENGSAS_LIBRARY_DIR}")
		FIND_LIBRARY(LIBENGSAS_TESTING_LIBRARY_RELEASE NAMES engsas-testing.dll libengsas-testing.dll HINTS "${LIBENGSAS_TESTING_LIBRARY_DIR}")
		FIND_LIBRARY(LIBENGSAS_TESTING_LIBRARY_DEBUG NAMES engsas-testingd.dll libengsas-testingd.dll HINTS "${LIBENGSAS_TESTING_LIBRARY_DIR}")
		SELECT_LIBRARY_CONFIGURATIONS(LIBENGSAS_TESTING)
		FIND_PATH(LIBENGSAS_TESTING_INCLUDE_DIR NAMES etesting.h HINTS "${LIBENGSAS_TESTING_LIBRARY_DIR}" PATH_SUFFIXES include/testing)
	ELSE(WIN32)
		FIND_PACKAGE(PkgConfig)
		pkg_check_modules(PC_LIBENGSAS_TESTING libengsas-testing)
		SET(LIBENGSAS_TESTING_DEFINITIONS ${PC_LIBENGSAS_CFLAGS_OTHER})
		FIND_LIBRARY(LIBENGSAS_TESTING_LIBRARIES
			WIN32_DEBUG_POSTFIX d
			NAMES engsas-testing
			HINTS "${PC_LIBENGSAS_LIBDIR}" "${PC_LIBENGSAS_LIBRARY_DIRS}"
		)
		FIND_PATH(LIBENGSAS_TESTING_INCLUDE_DIR etesting.h
			HINTS "${PC_LIBENGSAS_INCLUDEDIR}" "${PC_LIBENGSAS_INCLUDE_DIRS}"
			PATH_SUFFIXES testing
		)
	ENDIF (WIN32)

	find_package_handle_standard_args(LIBENGSAS_TESTING DEFAULT_MSG  LIBENGSAS_TESTING_LIBRARIES LIBENGSAS_TESTING_INCLUDE_DIR)

ENDIF (LIBENGSAS_TESTING_INCLUDE_DIR AND LIBENGSAS_TESTING_LIBRARIES)

###########################
#
# LibEngsas-charts
#
###########################

IF (LIBENGSAS_CHARTS_INCLUDE_DIR AND LIBENGSAS_CHARTS_LIBRARIES)
	# in cache already
	SET(LIBENGSAS_CHARTS_FOUND TRUE)
ELSE (LIBENGSAS_CHARTS_INCLUDE_DIR AND LIBENGSAS_CHARTS_LIBRARIES)
	IF (WIN32)
		SET(LIBENGSAS_CHARTS_LIBRARY_DIR ${LIBENGSAS_LIBRARY_DIR})
		FIND_LIBRARY(LIBENGSAS_CHARTS_LIBRARY_RELEASE NAMES engsas-charts.dll libengsas-charts.dll HINTS ${LIBENGSAS_CHARTS_LIBRARY_DIR})
		FIND_LIBRARY(LIBENGSAS_CHARTS_LIBRARY_DEBUG NAMES engsas-chartsd.dll libengsas-chartsd.dll HINTS ${LIBENGSAS_CHARTS_LIBRARY_DIR})
		SELECT_LIBRARY_CONFIGURATIONS(LIBENGSAS_CHARTS)
		FIND_PATH(LIBENGSAS_CHARTS_INCLUDE_DIR NAMES echarts.h HINTS "${LIBENGSAS_CHARTS_LIBRARY_DIR}" PATH_SUFFIXES include/charts)
	ELSE(WIN32)
		FIND_PACKAGE(PkgConfig)
		pkg_check_modules(PC_LIBENGSAS_CHARTS libengsas-charts)
		SET(LIBENGSAS_CHARTS_DEFINITIONS )
		FIND_LIBRARY(LIBENGSAS_CHARTS_LIBRARIES
			WIN32_DEBUG_POSTFIX d
			NAMES engsas-charts
			HINTS "${PC_LIBENGSAS_CHARTS_LIBDIR}" "${PC_LIBENGSAS_LIBRARY_DIRS}"
		)
		FIND_PATH(LIBENGSAS_CHARTS_INCLUDE_DIR echarts.h
			HINTS "${PC_LIBENGSAS_INCLUDEDIR}" "${PC_LIBENGSAS_INCLUDE_DIRS}"
			PATH_SUFFIXES charts
		)
	ENDIF (WIN32)

	find_package_handle_standard_args(LIBENGSAS_CHARTS DEFAULT_MSG  LIBENGSAS_CHARTS_LIBRARIES LIBENGSAS_CHARTS_INCLUDE_DIR)
ENDIF (LIBENGSAS_CHARTS_INCLUDE_DIR AND LIBENGSAS_CHARTS_LIBRARIES)


SET(LIBENGSAS_VERSION_MAJOR "0")
SET(LIBENGSAS_VERSION_MINOR "6")
SET(LIBENGSAS_VERSION_PATCH "0")
SET(LIBENGSAS_VERSION "0.6.0")
